@@ -42,6 +42,9 @@
 #include "map.h"
 #include "text.h"
 #include "SDL_rotozoom.h"
+#include "takeover.h"
+
+const SDL_VideoInfo *vid_info;/* info about current video mode */
 
 void PutPixel (SDL_Surface * surface, int x, int y, Uint32 pixel);
 int Load_Fonts (void);
@@ -270,10 +273,10 @@ DrawLineBetweenTiles( float x1 , float y1 , float x2 , float y2 , int Color )
 	  y2=tmp;
 	}
 
-      for ( i=0 ; i < (y2 - y1) * Block_Width ; i++ )
+      for ( i=0 ; i < (y2 - y1) * Block_Rect.w ; i++ )
 	{
-	  pixx = User_Rect.x + User_Rect.w/2 - Block_Width * (Me.pos.x - x1 );
-	  pixy = USER_FENSTER_CENTER_Y - Block_Height * (Me.pos.y - y1 ) + i ;
+	  pixx = User_Rect.x + User_Rect.w/2 - Block_Rect.w * (Me.pos.x - x1 );
+	  pixy = UserCenter_y - Block_Rect.h * (Me.pos.y - y1 ) + i ;
 	  if ( (pixx <= User_Rect.x) || 
 	       (pixx >= User_Rect.x + User_Rect.w -1) || 
 	       (pixy <= User_Rect.y ) || 
@@ -300,10 +303,10 @@ DrawLineBetweenTiles( float x1 , float y1 , float x2 , float y2 , int Color )
   // SDL_LockSurface( ne_screen );
 
   slope = ( y2 - y1 ) / (x2 - x1) ;
-  for ( i=0 ; i<(x2-x1)*Block_Width ; i++ )
+  for ( i=0 ; i<(x2-x1)*Block_Rect.w ; i++ )
     {
-      pixx=User_Rect.x + User_Rect.w/2 - Block_Width * (Me.pos.x - x1 ) + i;
-      pixy= USER_FENSTER_CENTER_Y - Block_Height * (Me.pos.y - y1 ) + i * slope ;
+      pixx=User_Rect.x + User_Rect.w/2 - Block_Rect.w * (Me.pos.x - x1 ) + i;
+      pixy= UserCenter_y - Block_Rect.h * (Me.pos.y - y1 ) + i * slope ;
       if ( (pixx <= User_Rect.x) || 
 	   (pixx >= User_Rect.x + User_Rect.w -1) || 
 	   (pixy <= User_Rect.y ) || 
@@ -333,7 +336,7 @@ TakeScreenshot(void)
   static int Number_Of_Screenshot=0;
   char *Screenshoot_Filename;
 
-  Screenshoot_Filename=malloc(100);
+  Screenshoot_Filename=MyMalloc(100);
   DebugPrintf (1, "\n\nScreenshoot function called.\n\n");
   sprintf( Screenshoot_Filename , "Screenshot_%d.bmp", Number_Of_Screenshot );
   DebugPrintf(1, "\n\nScreenshoot function: The Filename is: %s.\n\n" , Screenshoot_Filename );
@@ -386,34 +389,47 @@ MakeGridOnScreen( SDL_Rect* Grid_Rectangle )
  * and that.
  *
  ----------------------------------------------------------------------*/
-void DisplayImage( char *datafile )
+void
+DisplayImage(char *datafile)
 {
   SDL_Surface *image;
   
   image = IMG_Load(datafile);
   if ( image == NULL ) {
-    fprintf(stderr, "Couldn't load image %s: %s\n",
-	    datafile, IMG_GetError());
+    DebugPrintf(0, "ERROR: Couldn't load image %s: %s\n", datafile, IMG_GetError());
     Terminate(ERR);
   }
-
+  
+  if (GameConfig.scale != 1.0)
+    ScalePic (&image, GameConfig.scale);
+  
   SDL_BlitSurface(image, NULL, ne_screen, NULL);
 
   SDL_FreeSurface(image);
-}
+
+  return;
+
+} // DisplayImage()
 
 /*----------------------------------------------------------------------
  * This function resizes all blocks and structures involved in assembling
  * the combat picture to a new scale.  The new scale is relative to the
  * standard scale with means scale=1 is 64x64 tile size.
  *
+ * in the first call we assume the Block_Rect to be the original game-size
+ * and store this value for future rescalings
  ----------------------------------------------------------------------*/
 void 
 SetCombatScaleTo(float scale)
 {
   int i, j;
+  static SDL_Rect origBlock;
+  static bool firstcall = TRUE;
   SDL_Surface *tmp;
 
+  if (firstcall) Copy_Rect (Block_Rect, origBlock);   // keep that as a backup
+  firstcall = FALSE;
+
   for ( j=0 ; j < NUM_COLORS ; j++ )
     for ( i = 0 ; i < NUM_MAP_BLOCKS ; i++ )
       {
@@ -427,9 +443,8 @@ SetCombatScaleTo(float scale)
 	SDL_FreeSurface(tmp); // free the old surface
       }
 
-
-  Block_Width = INITIAL_BLOCK_WIDTH * scale;
-  Block_Height= INITIAL_BLOCK_HEIGHT* scale;
+  Copy_Rect (origBlock, Block_Rect);   // always scale with respect to original size!
+  ScaleRect(Block_Rect, scale);
 
   return;
 
@@ -523,14 +538,14 @@ not resolve.... Sorry, if that interrupts a major game of yours.....\n\
 #define DIGIT_THREE_POSITION_X_STRING "Third digit x :"
 #define DIGIT_THREE_POSITION_Y_STRING "Third digit y :"
 
-  ReadValueFromString (Data, DIGIT_ONE_POSITION_X_STRING, "%d", &First_Digit_Pos_X);
-  ReadValueFromString (Data, DIGIT_ONE_POSITION_Y_STRING, "%d", &First_Digit_Pos_Y);
+  ReadValueFromString (Data, DIGIT_ONE_POSITION_X_STRING, "%hd", &FirstDigit_Rect.x);
+  ReadValueFromString (Data, DIGIT_ONE_POSITION_Y_STRING, "%hd", &FirstDigit_Rect.y);
 
-  ReadValueFromString (Data, DIGIT_TWO_POSITION_X_STRING, "%d", &Second_Digit_Pos_X);
-  ReadValueFromString (Data, DIGIT_TWO_POSITION_Y_STRING, "%d", &Second_Digit_Pos_Y);
+  ReadValueFromString (Data, DIGIT_TWO_POSITION_X_STRING, "%hd", &SecondDigit_Rect.x);
+  ReadValueFromString (Data, DIGIT_TWO_POSITION_Y_STRING, "%hd", &SecondDigit_Rect.y);
 
-  ReadValueFromString (Data, DIGIT_THREE_POSITION_X_STRING, "%d", &Third_Digit_Pos_X);
-  ReadValueFromString (Data, DIGIT_THREE_POSITION_Y_STRING, "%d", &Third_Digit_Pos_Y);
+  ReadValueFromString (Data, DIGIT_THREE_POSITION_X_STRING, "%hd", &ThirdDigit_Rect.x);
+  ReadValueFromString (Data, DIGIT_THREE_POSITION_Y_STRING, "%hd", &ThirdDigit_Rect.y);
 
   free (Data);
 
@@ -555,8 +570,7 @@ InitPictures (void)
   char *fpath;
   int line, col, i;
   BFont_Info *oldfont;
-  SDL_Rect StdBlock, DigitBlock;
-  SDL_Surface *tmp_surf;
+  SDL_Surface *tmp;
   char fname[500];
 
   // Loading all these pictures might take a while...
@@ -566,17 +580,11 @@ InitPictures (void)
 
   oldfont = GetCurrentFont ();
 
-  // Important: Global variable containing the _actual_ block-sizes
-  Block_Width = INITIAL_BLOCK_WIDTH;
-  Block_Height = INITIAL_BLOCK_HEIGHT;
-
-  Set_Rect (StdBlock, 0, 0, Block_Width, Block_Height);
-  Set_Rect (DigitBlock, 0,0,INITIAL_DIGIT_WIDTH, INITIAL_DIGIT_HEIGHT);
-
-  Load_Fonts ();
+  if (first_call)
+    Load_Fonts ();
 
   SetCurrentFont (FPS_Display_BFont);
-  printf_SDL (ne_screen, User_Rect.x + 50, SCREENHEIGHT - 100, "Loading Theme config ...");
+  printf_SDL (ne_screen, User_Rect.x + 50, Screen_Rect.h - 100, "Loading Theme config ...");
 
   LoadThemeConfigurationFile();
 
@@ -589,9 +597,9 @@ InitPictures (void)
   for (line = 0; line < NUM_COLORS; line ++)
     for (col = 0; col < NUM_MAP_BLOCKS; col ++)
       {
-	FreeIfUsed (MapBlockSurfacePointer[line][col]);
-	MapBlockSurfacePointer[line][col] = Load_Block (NULL, line, col, &StdBlock,0);
-	OrigMapBlockSurfacePointer[line][col] = MapBlockSurfacePointer[line][col];
+	FreeIfUsed (OrigMapBlockSurfacePointer[line][col]);
+	OrigMapBlockSurfacePointer[line][col] = Load_Block (NULL, line, col, &OrigBlock_Rect,0); 
+	MapBlockSurfacePointer[line][col] = OrigMapBlockSurfacePointer[line][col];
       }
   printf_SDL (ne_screen, -1, -1, ".");
   //---------- get Droid-model  blocks
@@ -601,10 +609,11 @@ InitPictures (void)
     {
       FreeIfUsed (InfluencerSurfacePointer[col]);
       FreeIfUsed (EnemySurfacePointer[col]);
-      InfluencerSurfacePointer[col] = Load_Block (NULL, 0, col, &StdBlock, 0);
-      /* Influence pics are only used in _internal_ blits ==> clear per-surf alpha */
+      InfluencerSurfacePointer[col] = Load_Block (NULL, 0, col, &OrigBlock_Rect, 0);
+      EnemySurfacePointer[col] = Load_Block (NULL, 1, col, &OrigBlock_Rect, 0);
+      /* Droid pics are only used in _internal_ blits ==> clear per-surf alpha */
       SDL_SetAlpha (InfluencerSurfacePointer[col], 0, 0); 
-      EnemySurfacePointer[col] = Load_Block (NULL, 1, col, &StdBlock, 0);
+      SDL_SetAlpha (EnemySurfacePointer[col], 0, 0); 
     }
 
   //  SDL_SetAlpha( Me.pic, SDL_SRCALPHA, SDL_ALPHA_OPAQUE);
@@ -617,7 +626,7 @@ InitPictures (void)
     for (col = 0; col < Bulletmap[line].phases; col ++)
       {
 	FreeIfUsed (Bulletmap[line].SurfacePointer[col]);
-	Bulletmap[line].SurfacePointer[col] = Load_Block (NULL, line, col, &StdBlock, 0);
+	Bulletmap[line].SurfacePointer[col] = Load_Block (NULL, line, col, &OrigBlock_Rect, 0);
       }
   printf_SDL (ne_screen, -1, -1, ".");
 
@@ -628,7 +637,7 @@ InitPictures (void)
     for (col = 0; col < Blastmap[line].phases; col ++)
       {
 	FreeIfUsed (Blastmap[line].SurfacePointer[col]);
-	Blastmap[line].SurfacePointer[col] = Load_Block (NULL, line, col, &StdBlock, 0);
+	Blastmap[line].SurfacePointer[col] = Load_Block (NULL, line, col, &OrigBlock_Rect, 0);
       }
   printf_SDL (ne_screen, -1, -1, ".");
   //---------- get Digit blocks
@@ -637,9 +646,9 @@ InitPictures (void)
   for (col = 0; col < 10; col++)
     {
       FreeIfUsed (InfluDigitSurfacePointer[col]);
-      InfluDigitSurfacePointer[col] = Load_Block (NULL, 0, col, &DigitBlock, 0);
+      InfluDigitSurfacePointer[col] = Load_Block (NULL, 0, col, &OrigDigit_Rect, 0);
       FreeIfUsed (EnemyDigitSurfacePointer[col]);
-      EnemyDigitSurfacePointer[col] = Load_Block (NULL, 0, col + 10, &DigitBlock, 0);
+      EnemyDigitSurfacePointer[col] = Load_Block (NULL, 0, col + 10, &OrigDigit_Rect, 0);
     }
   printf_SDL (ne_screen, -1, -1, ".");
 
@@ -655,11 +664,11 @@ InitPictures (void)
   // the following are not theme-specific and are therefore only loaded once!
   if (first_call)
     {
-      //  create the local influ-pic storage by reading a  dummy-block 
-      tmp_surf = SDL_CreateRGBSurface( 0 , Block_Width, Block_Height, screen_bpp, 0, 0, 0, 0);
-      Me.pic = SDL_DisplayFormatAlpha( tmp_surf ); 
-      SDL_FreeSurface (tmp_surf);
-      
+      //  create the tmp block-build storage 
+      tmp = SDL_CreateRGBSurface( 0 , Block_Rect.w, Block_Rect.h, screen_bpp, 0, 0, 0, 0);
+      BuildBlock = SDL_DisplayFormatAlpha (tmp); 
+      SDL_FreeSurface (tmp);
+
       // takeover pics
       fpath = find_file (TAKEOVER_BG_PIC_FILE, GRAPHICS_DIR, NO_THEME, CRITICAL);
       takeover_bg_pic = Load_Block (fpath, 0, 0, NULL, 0);
@@ -717,14 +726,17 @@ InitPictures (void)
       else
 	{
 	  Load_Block (fpath, 0, 0, NULL, INIT_ONLY);
-	  Decal_pics[0] = Load_Block (NULL, 0, 0, &StdBlock, 0);
-	  Decal_pics[1] = Load_Block (NULL, 0, 1, &StdBlock, 0);
+	  Decal_pics[0] = Load_Block (NULL, 0, 0, &OrigBlock_Rect, 0);
+	  Decal_pics[1] = Load_Block (NULL, 0, 1, &OrigBlock_Rect, 0);
 	}
 
     } // if first_call
   
   printf_SDL (ne_screen, -1, -1, " ok\n");
 
+  // if scale != 1 then we need to rescale everything now
+  ScaleGraphics (GameConfig.scale);
+
   // make sure bullet-surfaces get re-generated!
   for ( i = 0 ; i < MAXBULLETS ; i++ )
     AllBullets[i].Surfaces_were_generated = FALSE ;
@@ -734,10 +746,15 @@ InitPictures (void)
   first_call = FALSE;
 
   return (TRUE);
-}				// InitPictures
 
-// load a pic into memory and return the SDL_RWops pointer to it
-SDL_RWops *load_raw_pic (char *fpath)
+}  // InitPictures
+
+
+/*----------------------------------------------------------------------
+ * load a pic into memory and return the SDL_RWops pointer to it
+ *----------------------------------------------------------------------*/
+SDL_RWops *
+load_raw_pic (char *fpath)
 {
     struct stat statbuf;
     FILE *fp;
@@ -750,11 +767,6 @@ SDL_RWops *load_raw_pic (char *fpath)
 	DebugPrintf (0, "ERROR: load_raw_pic() called with NULL argument!\n");
 	Terminate (ERR);
       }
-    if (stat(fpath, &statbuf) == -1) 
-      {
-	DebugPrintf (0, "ERROR: Couldn't stat file %s. Giving up\n", fpath);
-	Terminate (ERR);
-      }
 
     fp = fopen (fpath, "rb");
     if (!fp)
@@ -763,7 +775,7 @@ SDL_RWops *load_raw_pic (char *fpath)
 	Terminate (ERR);
       }
 
-    size = statbuf.st_size;
+    size = FS_filelength (fp);
     mem = MyMalloc (size);
     if (fread (mem, 1, size, fp) != size)
       {
@@ -784,6 +796,7 @@ SDL_RWops *load_raw_pic (char *fpath)
  * fpath: full pathname of picture-file; if NULL: use previous SDL-surf
  * line, col: block-position in pic-file to read block from
  * block: dimension of blocks to consider: if NULL: copy whole pic
+ * 	  NOTE: only w and h of block are used!!
  *
  * !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  * NOTE: to avoid memory-leaks, use (flags | INIT_ONLY) if you only
@@ -844,7 +857,7 @@ Load_Block (char *fpath, int line, int col, SDL_Rect * block, int flags)
 
   return (ret);
 
-}				/* Load_Block() */
+} // Load_Block()
 
 
 /*-----------------------------------------------------------------
@@ -855,8 +868,6 @@ Load_Block (char *fpath, int line, int col, SDL_Rect * block, int flags)
 void
 Init_Video (void)
 {
-  const SDL_VideoInfo *vid_info;
-  SDL_Rect **vid_modes;
   char vid_driver[81];
   Uint32 flags;  /* flags for SDL video mode */
   char *fpath;
@@ -887,11 +898,10 @@ Init_Video (void)
   vid_info = SDL_GetVideoInfo (); /* just curious */
   SDL_VideoDriverName (vid_driver, 80);
   
-  flags = SDL_SWSURFACE | SDL_HWPALETTE ;
+  //  flags = SDL_HWSURFACE | SDL_DOUBLEBUF;
+  flags = 0;
   if (GameConfig.UseFullscreen) flags |= SDL_FULLSCREEN;
 
-  vid_modes = SDL_ListModes (NULL, SDL_SWSURFACE);
-
   if (vid_info->wm_available)  /* if there's a window-manager */
     {
       SDL_WM_SetCaption ("Freedroid", "");
@@ -899,27 +909,18 @@ Init_Video (void)
       if (fpath) SDL_WM_SetIcon( IMG_Load (fpath), NULL);
     }
 
-
-  /* 
-   * currently only the simple 320x200 mode is supported for 
-   * simplicity, as all our graphics are in this format
-   * once this is up and running, we'll provide others modes
-   * as well.
-   */
   screen_bpp = 16; /* start with the simplest */
 
-  #define SCALE_FACTOR 2
-
-  if( !(ne_screen = SDL_SetVideoMode ( SCREENLEN, SCREENHEIGHT , 0 , flags)) )
+  if( !(ne_screen = SDL_SetVideoMode ( Screen_Rect.w, Screen_Rect.h , 0 , flags)) )
     {
-      fprintf(stderr, "Couldn't set (2*) 320x240*SCALE_FACTOR video mode: %s\n",
-	      SDL_GetError()); 
+      DebugPrintf (0, "ERORR: Couldn't set %d x %d video mode. SDL: %s\n",
+		   Screen_Rect.w, Screen_Rect.h, SDL_GetError()); 
       exit(-1);
     }
 
-  ne_vid_info = SDL_GetVideoInfo (); /* info about current video mode */
+  vid_info = SDL_GetVideoInfo (); /* info about current video mode */
 
-  TransparentPixel = SDL_MapRGB(ne_screen->format, 0, 0, 0); // colorkey = black at the mo
+  DebugPrintf(1, "Got video mode: ");
 
   SDL_SetGamma( 1 , 1 , 1 );
   GameConfig.Current_Gamma_Correction=1;
@@ -1025,18 +1026,16 @@ void putpixel(SDL_Surface *surface, int x, int y, Uint32 pixel)
     }
 } // void putpixel(...)
 
-
+/*----------------------------------------------------------------------
+ *
+ *----------------------------------------------------------------------*/
 int 
 Load_Fonts (void)
 {
   char *fpath;
 
-  // make sure this function is only called once, even if we do ReInit():
-  if (Para_BFont) 
-    return (OK);
-
   fpath = find_file (PARA_FONT_FILE, GRAPHICS_DIR, NO_THEME, CRITICAL);
-  if ( ( Para_BFont = LoadFont (fpath) ) == NULL )
+  if ( ( Para_BFont = LoadFont (fpath, GameConfig.scale) ) == NULL )
     {
       DebugPrintf (0, "ERROR: font file named %s was not found.\n", PARA_FONT_FILE );
       Terminate(ERR);
@@ -1046,7 +1045,7 @@ Load_Fonts (void)
   Menu_BFont = Para_BFont;
 
   fpath = find_file (FPS_FONT_FILE, GRAPHICS_DIR, NO_THEME, CRITICAL);
-  if ( ( FPS_Display_BFont = LoadFont (fpath) ) == NULL )
+  if ( ( FPS_Display_BFont = LoadFont (fpath, GameConfig.scale) ) == NULL )
     {
       DebugPrintf (0, "ERROR: font file named %s was not found.\n", FPS_FONT_FILE);
       Terminate(ERR);
@@ -1102,8 +1101,8 @@ white_noise (SDL_Surface *bitmap, SDL_Rect *rect, int timeout)
 
       for (x = 0; x < rect->w; x++)
 	for (y = 0; y < rect->h; y++)
-	  if (random()%100 > signal_strengh)
-	    PutPixel (noise_tiles[i], x, y, grey[random()%NOISE_COLORS]);
+	  if (rand()%100 > signal_strengh)
+	    PutPixel (noise_tiles[i], x, y, grey[rand()%NOISE_COLORS]);
 
       //      printf_SDL (ne_screen, -1, -1, " %d", i+1);
       //      SDL_BlitSurface (noise_tiles[i], NULL, ne_screen, rect);
@@ -1122,7 +1121,7 @@ white_noise (SDL_Surface *bitmap, SDL_Rect *rect, int timeout)
       // pick an old enough tile
       do
 	{
-	  next_tile = random()%NOISE_TILES;
+	  next_tile = rand()%NOISE_TILES;
 	  for (i = 0; i < sizeof(used_tiles); i++)
 	    {
 	      if (next_tile == used_tiles[i])
@@ -1141,7 +1140,7 @@ white_noise (SDL_Surface *bitmap, SDL_Rect *rect, int timeout)
       // set it
       SDL_BlitSurface (noise_tiles[next_tile], NULL, ne_screen, rect);
       SDL_UpdateRect (ne_screen, rect->x, rect->y, rect->w, rect->h);
-      usleep(25000);
+      SDL_Delay(25);
 
       if ( (timeout && (SDL_GetTicks()-now > timeout)))
 	break;
@@ -1157,5 +1156,220 @@ white_noise (SDL_Surface *bitmap, SDL_Rect *rect, int timeout)
   return;
 }
 
+/*----------------------------------------------------------------------
+ * ScaleGraphics ()
+ *----------------------------------------------------------------------*/
+void
+ScaleGraphics (float scale)
+{
+  static bool first_call = TRUE;
+  SDL_Surface *tmp;
+  int line, col, i, j;
+
+  if (scale == 1.0)
+    return;
+
+  // these are reset in a theme-change by the theme-config-file
+  // therefore we need to rescale them each time again
+  ScaleRect (FirstDigit_Rect, scale);
+  ScaleRect (SecondDigit_Rect, scale);
+  ScaleRect (ThirdDigit_Rect, scale);
+  
+
+  // note: only rescale these rects the first time!!
+  if (first_call)
+    ScaleStatRects (scale);
+
+  printf_SDL (ne_screen, User_Rect.x + 50, -1, "Rescaling graphics ...");
+
+  //---------- rescale Map blocks
+  for (line = 0; line < NUM_COLORS; line ++)
+    for (col = 0; col < NUM_MAP_BLOCKS; col ++)
+      {
+	ScalePic( &OrigMapBlockSurfacePointer[line][col], scale);
+	MapBlockSurfacePointer[line][col] = OrigMapBlockSurfacePointer[line][col];
+      }
+  printf_SDL (ne_screen, -1, -1, ".");
+  //---------- rescale Droid-model  blocks
+  for (col = 0; col < DROID_PHASES; col ++) 
+    {
+      ScalePic (&InfluencerSurfacePointer[col], scale);
+      ScalePic (&EnemySurfacePointer[col], scale);
+      /* Droid pics are only used in _internal_ blits ==> clear per-surf alpha */
+      SDL_SetAlpha (InfluencerSurfacePointer[col], 0, 0); 
+      SDL_SetAlpha (EnemySurfacePointer[col], 0, 0); 
+    }
+
+  printf_SDL (ne_screen, -1, -1, ".");
+  //---------- rescale Bullet blocks
+  for (line = 0; line < Number_Of_Bullet_Types; line ++)
+    for (col = 0; col < Bulletmap[line].phases; col ++)
+      ScalePic( &Bulletmap[line].SurfacePointer[col], scale);
+
+  printf_SDL (ne_screen, -1, -1, ".");
+
+  //---------- rescale Blast blocks
+  for (line = 0; line <  ALLBLASTTYPES; line ++)
+    for (col = 0; col < Blastmap[line].phases; col ++)
+      ScalePic (&Blastmap[line].SurfacePointer[col], scale);
+
+  printf_SDL (ne_screen, -1, -1, ".");
+  //---------- rescale Digit blocks
+  for (col = 0; col < 10; col++)
+    {
+      ScalePic (&InfluDigitSurfacePointer[col], scale);
+      ScalePic (&EnemyDigitSurfacePointer[col], scale);
+      /* Digits are only used in _internal_ blits ==> clear per-surf alpha */
+      SDL_SetAlpha (InfluDigitSurfacePointer[col], 0, 0); 
+      SDL_SetAlpha (EnemyDigitSurfacePointer[col], 0, 0); 
+    }
+  printf_SDL (ne_screen, -1, -1, ".");
+
+  //---------- rescale Takeover pics
+  ScalePic (&to_blocks, scale);
+  printf_SDL (ne_screen, -1, -1, ".");
+
+  ScalePic (&ship_on_pic, scale);
+  ScalePic (&ship_off_pic, scale);
+
+  // the following are not theme-specific and are therefore only loaded once!
+  if (first_call)
+    {
+      //  create a new tmp block-build storage 
+      FreeIfUsed (BuildBlock);
+      tmp = SDL_CreateRGBSurface( 0 , Block_Rect.w, Block_Rect.h, screen_bpp, 0, 0, 0, 0);
+      BuildBlock = SDL_DisplayFormatAlpha (tmp); 
+      SDL_FreeSurface (tmp);
+
+      // takeover pics
+      ScalePic (&takeover_bg_pic, scale);
+
+      //---------- Console pictures
+      ScalePic (&console_pic, scale);
+      ScalePic (&console_bg_pic1, scale);
+      ScalePic (&console_bg_pic2, scale);
+      ScalePic (&arrow_up, scale);
+      ScalePic (&arrow_down, scale);
+      ScalePic (&arrow_right, scale);
+      ScalePic (&arrow_left, scale);
+      //---------- Banner
+      ScalePic (&banner_pic, scale);
+
+      //---------- Droid images ----------
+      // FIXME: this still needs to be done!!!!
+      for (i=0; i<NUM_DROIDS; i++)
+	{
+	  //	  packed_portraits[i] = load_raw_pic (fpath);
+	}
+
+      // we need the 999.png in any case for transparency!
+      ScalePic (&pic999, scale);
+
+      // get the Ashes pics
+      if (Decal_pics[0]) ScalePic (&Decal_pics[0], scale);
+      if (Decal_pics[1]) ScalePic (&Decal_pics[1], scale);
+
+    } // if first_call
+  
+  printf_SDL (ne_screen, -1, -1, " ok\n");
+
+  first_call = FALSE;
+
+  return;
+
+} // ScaleGraphics()
+
+/*----------------------------------------------------------------------
+ * 
+ *----------------------------------------------------------------------*/
+void
+ScalePic (SDL_Surface **pic, float scale)
+{
+  SDL_Surface *tmp;
+
+  if (scale == 1.0)
+    return;
+
+  tmp = *pic;
+  *pic = zoomSurface (tmp, scale, scale, 0);
+  SDL_FreeSurface (tmp);
+
+  return;
+
+} // ScalePic ()
+
+/*----------------------------------------------------------------------
+ * scale all "static" rectangle
+ *----------------------------------------------------------------------*/
+void
+ScaleStatRects (float scale)
+{
+  int i, j;
+
+  ScaleRect (Block_Rect, scale);
+  ScaleRect (User_Rect, scale);
+  ScaleRect (Classic_User_Rect, scale);
+  ScaleRect (Full_User_Rect, scale);
+  ScaleRect (Banner_Rect, scale);
+  ScaleRect (Portrait_Rect, scale);
+  ScaleRect (Cons_Droid_Rect, scale);
+  ScaleRect (Menu_Rect, scale);
+  ScaleRect (OptionsMenu_Rect, scale);
+  ScaleRect (Digit_Rect, scale);
+  ScaleRect (Cons_Header_Rect, scale);
+  ScaleRect (Cons_Menu_Rect, scale);
+  ScaleRect (Cons_Text_Rect, scale);
+  
+  ScaleRect (Cons_Menu_Rects[0], scale);
+  ScaleRect (Cons_Menu_Rects[1], scale);
+  ScaleRect (Cons_Menu_Rects[2], scale);
+  ScaleRect (Cons_Menu_Rects[3], scale);
+
+  ScaleRect (ConsMenuItem_Rect, scale);
+  
+  ScaleRect (LeftInfo_Rect, scale);
+  ScaleRect (RightInfo_Rect, scale);
+  
+  for (i=0; i<NUM_FILL_BLOCKS; i++)
+    ScaleRect (FillBlocks[i], scale);
+  
+  for (i = 0; i < NUM_CAPS_BLOCKS; i++)
+    ScaleRect (CapsuleBlocks[i], scale);
+  
+  for (j = 0; j < 2*NUM_PHASES; j++)
+    for (i = 0; i < TO_BLOCKS; i++)
+      ScaleRect (ToGameBlocks[j*TO_BLOCKS+i], scale);
+
+  for (i = 0; i < NUM_GROUND_BLOCKS; i++)
+    ScaleRect (ToGroundBlocks[i], scale);
+  
+  ScaleRect (ToColumnBlock, scale);
+  ScaleRect (ToLeaderBlock, scale);
+
+
+  for (i=0; i < TO_COLORS; i++)
+    {
+      ScalePoint (LeftCapsulesStart[i],scale);
+      ScalePoint (CurCapsuleStart[i],scale);
+      ScalePoint (PlaygroundStart[i],scale);
+      ScalePoint (DruidStart[i],scale);
+    }
+  ScalePoint (TO_LeftGroundStart, scale);
+  ScalePoint (TO_ColumnStart, scale);
+  ScalePoint (TO_RightGroundStart, scale);
+  ScalePoint( TO_LeaderBlockStart, scale);
+
+  ScaleRect (TO_FillBlock, scale);
+  ScaleRect (TO_ElementRect, scale);
+  ScaleRect (TO_CapsuleRect, scale);
+  ScaleRect (TO_LeaderLed, scale);
+  ScaleRect (TO_GroundRect, scale);
+  ScaleRect (TO_ColumnRect, scale);
+
+  return;
+
+} // ScaleStatRects()
+
+
 
 #undef _graphics_c
