@@ -38,6 +38,7 @@
 #include "global.h"
 #include "proto.h"
 #include "text.h"
+#include "getopt.h"   
 
 void Init_Game_Data( char* Datafilename );
 void Get_Bullet_Data ( char* DataPointer );
@@ -511,6 +512,7 @@ char usage_string[] =
                     [-f|--fullscreen] [-w|--window]\n\
                     [-j|--sensitivity]\n\
                     [-d|--debug=LEVEL]\n\
+                    [-r|--scale=RESOLUTION_SCALE]\n\
 \n\
 Please report bugs on our sourceforge-website:\n\
 http://sourceforge.net/projects/freedroid/\n\n";
@@ -526,23 +528,23 @@ parse_command_line (int argc, char *const argv[])
   int timeout_time;		/* timeout to restore text-mode */
 
   static struct option long_options[] = {
-    {"version", 0, 0, 'v'},
-    {"help", 	0, 0, 'h'},
-    {"nosound", 0, 0, 'q'},
-    {"sound", 	0, 0, 's'},
-    {"timeout", 1, 0, 't'},
-    {"debug", 	2, 0, 'd'},
-    {"window",  0, 0, 'w'},
-    {"fullscreen",0,0,'f'},
-    {"sensitivity",1,0,'j'},
-    { 0, 	0, 0,  0}
+    {"version", 	0, 0, 'v'},
+    {"help", 		0, 0, 'h'},
+    {"nosound", 	0, 0, 'q'},
+    {"sound", 		0, 0, 's'},
+    {"debug", 		2, 0, 'd'},
+    {"window",  	0, 0, 'w'},
+    {"fullscreen",	0, 0, 'f'},
+    {"sensitivity",	1, 0, 'j'},
+    {"scale",		1, 0, 'r'},
+    { 0, 		0, 0,  0}
   };
 
   //   sound_on=TRUE;
 
   while (1)
     {
-      c = getopt_long (argc, argv, "vqst:h?d::wfj:", long_options, NULL);
+      c = getopt_long (argc, argv, "vqst:h?d::wfj:r:", long_options, NULL);
       if (c == -1)
 	break;
 
@@ -570,14 +572,6 @@ parse_command_line (int argc, char *const argv[])
 	  sound_on = TRUE;
 	  break;
 
-	case 't':
-	  timeout_time = atoi (optarg);
-	  if (timeout_time > 0)
-	    {
-	      signal (SIGALRM, timeout);
-	      alarm (timeout_time);	/* Terminate after some seconds for safety. */
-	    }
-	  break;
 	case 'j':
 	  joy_sensitivity = atoi (optarg);
 	  if (joy_sensitivity < 0 || joy_sensitivity > 32)
@@ -594,6 +588,16 @@ parse_command_line (int argc, char *const argv[])
 	    debug_level = atoi (optarg);
 	  break;
 
+	case 'r':
+	  GameConfig.scale = (float)atof (optarg);
+	  if (GameConfig.scale == 0)
+	    {
+	      DebugPrintf (0, "ERROR: illegal scale entered: %s\n", optarg);
+	      Terminate (ERR);
+	    }
+	  DebugPrintf (1, "Graphics scale set to %f\n", GameConfig.scale);
+	  break;
+
 	case 'f':
 	  GameConfig.UseFullscreen = TRUE;
 	  break;
@@ -859,8 +863,6 @@ InitNewMission ( char *MissionName )
   Me.phase = 0;
   Me.timer = 0.0;  // set clock to 0
 
-  RealScore = 0.0;
-
   DebugPrintf (1, "done."); // this matches the printf at the beginning of this function
 
   free (MainMissionPointer);
@@ -903,13 +905,14 @@ InitFreedroid (int argc, char *const argv[])
   GameConfig.Draw_Energy = TRUE;
   GameConfig.Draw_DeathCount = FALSE;
   GameConfig.Draw_Position = FALSE;
-  // this is the "classic" version, so defaults are set on "classic"
+
   sprintf (GameConfig.Theme_Name, "classic");
-  GameConfig.FullUserRect = FALSE;
+  GameConfig.FullUserRect = TRUE;
   GameConfig.UseFullscreen = FALSE;
   GameConfig.TakeoverActivates = TRUE;  
-  GameConfig.ShowDecals = FALSE;
+  GameConfig.ShowDecals = TRUE;
   GameConfig.AllMapVisible = TRUE;    // classic setting: map always visible
+  GameConfig.scale = 1.0;  	 // overall scaling of _all_ graphics (e.g. for 320x200 displays)
 
   // now load saved options from the config-file
   LoadGameConfig ();
@@ -925,7 +928,7 @@ InitFreedroid (int argc, char *const argv[])
 
   FindAllThemes ();  // put all found themes into a list: AllThemes[]
 
-
+  ScaleRect (Screen_Rect, GameConfig.scale);   // make sure we open a window of the right (rescaled) size!
   Init_Video ();
 
   DisplayImage (find_file (TITLE_PIC_FILE, GRAPHICS_DIR, NO_THEME, CRITICAL)); // show title pic
@@ -995,13 +998,14 @@ Title ( char *MissionBriefingPointer )
   SDL_SetClipRect ( ne_screen, NULL );
   ReadValueFromString (MissionBriefingPointer, BRIEFING_TITLE_PICTURE_STRING, "%s", Buffer);
   DisplayImage ( find_file(Buffer, GRAPHICS_DIR, NO_THEME, CRITICAL) );
-  MakeGridOnScreen( (SDL_Rect*) &Full_Screen_Rect );
+  MakeGridOnScreen( (SDL_Rect*) &Screen_Rect );
   Me.status=BRIEFING;
-  DisplayBanner (NULL, NULL,  BANNER_FORCE_UPDATE ); 
-  SDL_Flip (ne_screen);
+  //  SDL_Flip (ne_screen);
 
   SetCurrentFont( Para_BFont );
 
+  DisplayBanner (NULL, NULL,  BANNER_FORCE_UPDATE ); 
+
   // Next we display all the subsections of the briefing section
   // with scrolling font
   NextSubsectionStartPointer = MissionBriefingPointer;
@@ -1091,6 +1095,7 @@ ThouArtDefeated (void)
 {
   Uint32 now, delay;
   SDL_Rect dst;
+  int h;
 
   Me.status = TERMINATED;
   SDL_ShowCursor (SDL_DISABLE);
@@ -1113,7 +1118,9 @@ ThouArtDefeated (void)
       ComputeFPSForThisFrame ();
     }
   
+#ifdef HAVE_LIBSDL_MIXER
   Mix_HaltMusic ();
+#endif
 
   // important!!: don't forget to stop fps calculation here (bugfix: enemy piles after gameOver)
   Activate_Conservative_Frame_Computation ();
@@ -1123,19 +1130,21 @@ ThouArtDefeated (void)
   Assemble_Combat_Picture (DO_SCREEN_UPDATE);
   MakeGridOnScreen (&User_Rect);
 
-  Set_Rect (dst, UserCenter_x -70, UserCenter_y - 80, Portrait_Rect.w, Portrait_Rect.h);
+  Set_Rect (dst, UserCenter_x - Portrait_Rect.w/2, UserCenter_y - Portrait_Rect.h/2, 
+	    Portrait_Rect.w, Portrait_Rect.h);
   SDL_BlitSurface (pic999, NULL, ne_screen, &dst);
   ThouArtDefeatedSound ();
 
   SetCurrentFont (Para_BFont);
-  DisplayText ("Transmission", UserCenter_x -90, UserCenter_y - 100, &User_Rect);
-  DisplayText ("Terminated", UserCenter_x -90, UserCenter_y + 100, &User_Rect);
+  h = FontHeight (Para_BFont);
+  DisplayText ("Transmission", dst.x - h, dst.y - h, &User_Rect);
+  DisplayText ("Terminated",  dst.x -h, dst.y + dst.h, &User_Rect);
   printf_SDL(ne_screen, -1, -1, "\n");
   SDL_Flip (ne_screen);
   
   now = SDL_GetTicks ();
 
-  while (SDL_GetTicks() - now < SHOW_WAIT) usleep(50);
+  while (SDL_GetTicks() - now < SHOW_WAIT) SDL_Delay(1);
 
   UpdateHighscores ();
 
@@ -1195,7 +1204,7 @@ FindAllThemes (void)
   for (location=0; location < 2; location++)
     {
       if (location == 0)
-	strcpy (dname, DATADIR);   /* first scan DATADIR */
+	strcpy (dname, FD_DATADIR);   /* first scan FD_DATADIR */
       if (location == 1)
 	strcpy (dname, ".."); /* then the local graphics-dir */
 
@@ -1299,4 +1308,32 @@ FindAllThemes (void)
 
 } // FindAllThemes
 
+/*----------------------------------------------------------------------
+ * put some ideology message for our poor friends enslaved by M$-Win32 ;)
+ *----------------------------------------------------------------------*/
+void
+Win32Disclaimer (void)
+{
+  SDL_Rect rect;
+
+  SDL_SetClipRect ( ne_screen, NULL );
+  DisplayImage (find_file (TITLE_PIC_FILE, GRAPHICS_DIR, NO_THEME, CRITICAL)); // show title pic
+  MakeGridOnScreen( (SDL_Rect*) &Screen_Rect );
+
+  SetCurrentFont( Para_BFont );
+
+  Copy_Rect(Full_User_Rect, rect);
+  rect.x += 10;
+  rect.w -= 10; //leave some border
+  DisplayText ("Windows disclaimer:\n\nThis program is 100% Free (as in Freedom), licenced under the GPL.\n\
+It is developed on a free operating system (GNU/Linux) using exclusively free tools. \
+For more information about Free Software see the GPL licence (in the file COPYING)\n\
+or visit http://www.gnu.org.\n\n\n Press fire to play.", rect.x, rect.y, &rect);
+  SDL_Flip (ne_screen);
+  Wait4Fire();
+
+  return;
+}
+
+
 #undef _init_c
