@@ -56,12 +56,6 @@ void CreateWaypoint (level *level, int BlockX, int BlockY);
 void GraphicsSound_Options_Menu (void);
 void On_Screen_Display_Options_Menu (void);
 
-#define FIRST_MENU_ITEM_POS_X (2*INITIAL_BLOCK_WIDTH)
-#define FIRST_MENU_ITEM_POS_Y (USERFENSTERPOSY + FontHeight(Menu_BFont))
-#define OPTIONS_MENU_ITEM_POS_X (UserCenter_x - 120)
-#define FIRST_MIS_SELECT_ITEM_POS_X 0.0
-#define FIRST_MIS_SELECT_ITEM_POS_Y (USERFENSTERPOSY + FontHeight(Menu_BFont))
-
 EXTERN int MyCursorX;
 EXTERN int MyCursorY;
 
@@ -123,7 +117,7 @@ QuitGameMenu (void)
 	      User_Rect.y + User_Rect.h/2, "Do you really want to quit? (y/n) ");
   SDL_Flip (ne_screen);
 
-  while ( (!KeyIsPressed('n')) && (!KeyIsPressed('y')) ) usleep(50);
+  while ( (!KeyIsPressed('n')) && (!KeyIsPressed('y')) ) SDL_Delay(1);
   if (KeyIsPressed('y'))
     Terminate (OK);
 }
@@ -164,25 +158,25 @@ EscapeMenu (void)
       key = FALSE;
       SDL_BlitSurface (Menu_Background, NULL, ne_screen, NULL);
 
-      PutInfluence (FIRST_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y + (MenuPosition-1.5)*fheight);
+      PutInfluence (Menu_Rect.x, Menu_Rect.y + (MenuPosition-1.5)*fheight);
 
 
       pos = 0;
 
-      PutString (ne_screen, OPTIONS_MENU_ITEM_POS_X,FIRST_MENU_ITEM_POS_Y+(pos++)*fheight, "Back to Game");
-      PutString (ne_screen, OPTIONS_MENU_ITEM_POS_X,FIRST_MENU_ITEM_POS_Y+(pos++)*fheight,"Graphics & Sound" );
-      PutString (ne_screen, OPTIONS_MENU_ITEM_POS_X,FIRST_MENU_ITEM_POS_Y+(pos++)*fheight,"On-Screen Displays" );
-      PutString (ne_screen, OPTIONS_MENU_ITEM_POS_X,FIRST_MENU_ITEM_POS_Y+(pos++)*fheight,"Legacy Options");
-      PutString (ne_screen, OPTIONS_MENU_ITEM_POS_X,FIRST_MENU_ITEM_POS_Y+(pos++)*fheight, "Level Editor");
-      PutString (ne_screen, OPTIONS_MENU_ITEM_POS_X,FIRST_MENU_ITEM_POS_Y+(pos++)*fheight, "Highscores");
-      PutString (ne_screen, OPTIONS_MENU_ITEM_POS_X,FIRST_MENU_ITEM_POS_Y +(pos++)*fheight, "Credits");
-      PutString (ne_screen, OPTIONS_MENU_ITEM_POS_X,FIRST_MENU_ITEM_POS_Y +(pos++)*fheight, "Quit Game");
+      PutString (ne_screen, OptionsMenu_Rect.x,Menu_Rect.y+(pos++)*fheight, "Back to Game");
+      PutString (ne_screen, OptionsMenu_Rect.x,Menu_Rect.y+(pos++)*fheight,"Graphics & Sound" );
+      PutString (ne_screen, OptionsMenu_Rect.x,Menu_Rect.y+(pos++)*fheight,"On-Screen Displays" );
+      PutString (ne_screen, OptionsMenu_Rect.x,Menu_Rect.y+(pos++)*fheight,"Legacy Options");
+      PutString (ne_screen, OptionsMenu_Rect.x,Menu_Rect.y+(pos++)*fheight, "Level Editor");
+      PutString (ne_screen, OptionsMenu_Rect.x,Menu_Rect.y+(pos++)*fheight, "Highscores");
+      PutString (ne_screen, OptionsMenu_Rect.x,Menu_Rect.y +(pos++)*fheight, "Credits");
+      PutString (ne_screen, OptionsMenu_Rect.x,Menu_Rect.y +(pos++)*fheight, "Quit Game");
 
       SDL_Flip( ne_screen );
 
       while (!key)
 	{
-	  usleep (50);
+	  SDL_Delay (1);
 
 	  if (EscapePressedR() )
 	    {
@@ -311,28 +305,28 @@ enum
 
 
 
-      PutInfluence( FIRST_MENU_ITEM_POS_X,
-		    FIRST_MENU_ITEM_POS_Y + ( MenuPosition - 1.5 ) *fheight);
+      PutInfluence( Menu_Rect.x,
+		    Menu_Rect.y + ( MenuPosition - 1.5 ) *fheight);
       pos = 0;
 
-      PutString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+(pos++)*fheight, 
+      PutString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+(pos++)*fheight, 
 		 "Set to Strictly Classic");
 
-      PutString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+(pos++)*fheight, window_string);
-      PutString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+(pos++)*fheight, theme_string);
+      PutString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+(pos++)*fheight, window_string);
+      PutString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+(pos++)*fheight, theme_string);
 
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+(pos++)*fheight,
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+(pos++)*fheight,
 		   "Droid Talk : %s", GameConfig.Droid_Talk ? "ON" : "OFF");
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+(pos++)*fheight,
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+(pos++)*fheight,
 		   "Show Decals : %s", GameConfig.ShowDecals ? "ON" : "OFF");
 
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+(pos++)*fheight,
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+(pos++)*fheight,
 		   "All Map Visible: %s", GameConfig.AllMapVisible ? "ON" : "OFF");
 
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+(pos++)*fheight,
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+(pos++)*fheight,
 		   "Transfer = Activate: %s", GameConfig.TakeoverActivates ? "YES":"NO" );
 
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+(pos++)*fheight, 
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+(pos++)*fheight, 
 		   "Back");
 
       SDL_Flip( ne_screen );
@@ -340,7 +334,7 @@ enum
       while (!key)
 	{
 
-	  usleep(50);
+	  SDL_Delay(1);
 
 	  if ( EscapePressedR () )
 	    {
@@ -523,22 +517,22 @@ enum
       key = FALSE;
       SDL_BlitSurface (Menu_Background, NULL, ne_screen, NULL);
 
-      PutInfluence (FIRST_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+ (MenuPosition-1.5)*fheight);
+      PutInfluence (Menu_Rect.x, Menu_Rect.y+ (MenuPosition-1.5)*fheight);
 
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+0*fheight, 
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+0*fheight, 
 		   "Background Music: %1.2f" , GameConfig.Current_BG_Music_Volume );
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+1*fheight,  
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+1*fheight,  
 		   "Sound Effects: %1.2f", GameConfig.Current_Sound_FX_Volume );
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+2*fheight,  
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+2*fheight,  
 		   "Gamma: %1.2f", GameConfig.Current_Gamma_Correction );
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+3*fheight, 
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+3*fheight, 
 		   "Fullscreen Mode: %s", GameConfig.UseFullscreen ? "ON" : "OFF");
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+4*fheight, "Back");
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+4*fheight, "Back");
       SDL_Flip( ne_screen );
 
       while (!key)
 	{
-	  usleep (50);
+	  SDL_Delay (1);
 
 	  if ( EscapePressedR () )
 	    {
@@ -676,25 +670,25 @@ enum
       key = FALSE;
       SDL_BlitSurface (Menu_Background, NULL, ne_screen, NULL);
       
-      PutInfluence (FIRST_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y + (MenuPosition-1.5)*fheight);
+      PutInfluence (Menu_Rect.x, Menu_Rect.y + (MenuPosition-1.5)*fheight);
 
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+0*fheight, 
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+0*fheight, 
 		   "Show Position: %s", GameConfig.Draw_Position ? "ON" : "OFF");
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+1*fheight,
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+1*fheight,
 		   "Show Framerate: %s", GameConfig.Draw_Framerate? "ON" : "OFF");
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+2*fheight,
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+2*fheight,
 		   "Show Energy: %s", GameConfig.Draw_Energy? "ON" : "OFF");
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+3*fheight,
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+3*fheight,
 		   "Show DeathCount: %s", GameConfig.Draw_DeathCount ? "ON" : "OFF");
 
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y+4*fheight, "Back");
+      PrintString (ne_screen, OptionsMenu_Rect.x, Menu_Rect.y+4*fheight, "Back");
 
       SDL_Flip( ne_screen );
 
       while (!key)
 	{
 
-	  usleep(50);
+	  SDL_Delay(1);
 
 	  if ( EscapePressedR() )
 	    {
@@ -765,45 +759,45 @@ enum
 void
 Credits_Menu (void)
 {
-  int h; 
+  int h, em; 
   SDL_Rect screen;
   h = FontHeight(Menu_BFont);
+  em = CharWidth (Menu_BFont, 'm');
   
-  Copy_Rect (Full_Screen_Rect, screen);
+  Copy_Rect (Screen_Rect, screen);
   SDL_SetClipRect( ne_screen, NULL );
-  DisplayImage ( find_file(CREDITS_PIC_FILE, GRAPHICS_DIR, NO_THEME, CRITICAL) );
+  DisplayImage ( find_file(CREDITS_PIC_FILE, GRAPHICS_DIR, NO_THEME, CRITICAL));
   MakeGridOnScreen (&screen);
 
 
-  printf_SDL (ne_screen, User_Rect.w/2 - 20, 20, "CREDITS\n");
+  printf_SDL (ne_screen, UserCenter_x - 2*em, h, "CREDITS\n");
 
-  printf_SDL (ne_screen, 20, -1, "PROGRAMMING:");
-  printf_SDL (ne_screen, 2*User_Rect.w/3, -1, "Johannes Prix\n");
+  printf_SDL (ne_screen, em, -1, "PROGRAMMING:");
+  printf_SDL (ne_screen, 2*Full_User_Rect.w/3, -1, "Johannes Prix\n");
   printf_SDL (ne_screen, -1, -1, "Reinhard Prix\n");
   printf_SDL (ne_screen, -1, -1, "\n");
 
-  printf_SDL (ne_screen, 20, -1, "ARTWORK:");
+  printf_SDL (ne_screen, em, -1, "ARTWORK:");
   printf_SDL (ne_screen, 2*User_Rect.w/3, -1, "Bastian Salmela\n");
   printf_SDL (ne_screen, -1 , -1, "Lanzz\n");
-  printf_SDL (ne_screen, -1, -1, "\n");
 
-  printf_SDL (ne_screen, 20, -1, "C64 LEGACY MUSIC mods:\n");
+  printf_SDL (ne_screen, em, -1, "C64 LEGACY MUSIC mods:\n");
 
-  printf_SDL (ne_screen, 20, -1, "#dreamfish/trsi:");
-  printf_SDL (ne_screen, User_Rect.w/2 +40, -1, "Green Beret, Sanxion,\n");
-  printf_SDL (ne_screen, User_Rect.w/2 +40, -1, "Uridium2\n");
+  printf_SDL (ne_screen, em, -1, "#dreamfish/trsi:");
+  printf_SDL (ne_screen, Full_User_Rect.w/2, -1, "Green Beret, Sanxion,\n");
+  printf_SDL (ne_screen, Full_User_Rect.w/2, -1, "Uridium2\n");
 
-  printf_SDL (ne_screen, 20, -1, "4-mat:");
-  printf_SDL (ne_screen, User_Rect.w/2 +40, -1, "The last V8, Anarchy\n");
+  printf_SDL (ne_screen, em, -1, "4-mat:");
+  printf_SDL (ne_screen, Full_User_Rect.w/2, -1, "The last V8, Anarchy\n");
 
-  printf_SDL (ne_screen, 20, -1, "Kollaps:");
-  printf_SDL (ne_screen, User_Rect.w/2 +40, -1, "Tron\n");
+  printf_SDL (ne_screen, em, -1, "Kollaps:");
+  printf_SDL (ne_screen, Full_User_Rect.w/2, -1, "Tron\n");
 
-  printf_SDL (ne_screen, 20, -1, "Nashua:");
-  printf_SDL (ne_screen, User_Rect.w/2 +40, -1, "Starpaws\n");
+  printf_SDL (ne_screen, em, -1, "Nashua:");
+  printf_SDL (ne_screen, Full_User_Rect.w/2, -1, "Starpaws\n");
   
-  printf_SDL (ne_screen, 20, -1, "Android:");
-  printf_SDL (ne_screen, User_Rect.w/2 +40, -1, "Commando\n");
+  printf_SDL (ne_screen, em, -1, "Android:");
+  printf_SDL (ne_screen, Full_User_Rect.w/2, -1, "Commando\n");
 
   SDL_Flip( ne_screen );
 
@@ -828,57 +822,57 @@ Highlight_Current_Block(void)
 
   SDL_LockSurface( ne_screen );
 
-  for (i=0; i<Block_Width; i++)
+  for (i=0; i<Block_Rect.w; i++)
     {
       // This draws a (double) line at the upper border of the current block
       putpixel( ne_screen , 
-		i + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x - 0.5) * Block_Width , 
-		USER_FENSTER_CENTER_Y + ( rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Height , 
+		i + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x - 0.5) * Block_Rect.w , 
+		UserCenter_y + ( rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Rect.h , 
 		HIGHLIGHTCOLOR );
       putpixel( ne_screen , 
-		i + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x - 0.5) * Block_Width , 
-		USER_FENSTER_CENTER_Y + ( rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Height + 1 , 
+		i + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x - 0.5) * Block_Rect.w , 
+		UserCenter_y + ( rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Rect.h + 1 , 
 		HIGHLIGHTCOLOR );
 
       // This draws a line at the lower border of the current block
       putpixel( ne_screen , 
-		i + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x - 0.5) * Block_Width , 
-		USER_FENSTER_CENTER_Y + ( rintf(Me.pos.y)-Me.pos.y + 0.5 ) * Block_Height - 1, 
+		i + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x - 0.5) * Block_Rect.w , 
+		UserCenter_y + ( rintf(Me.pos.y)-Me.pos.y + 0.5 ) * Block_Rect.h - 1, 
 		HIGHLIGHTCOLOR );
       putpixel( ne_screen , 
-		i + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x - 0.5) * Block_Width , 
-		USER_FENSTER_CENTER_Y + ( rintf(Me.pos.y)-Me.pos.y + 0.5 ) * Block_Height - 2, 
+		i + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x - 0.5) * Block_Rect.w , 
+		UserCenter_y + ( rintf(Me.pos.y)-Me.pos.y + 0.5 ) * Block_Rect.h - 2, 
 		HIGHLIGHTCOLOR );
 
       // This draws a line at the left border of the current block
       putpixel( ne_screen , 
-		0 + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x - 0.5) * Block_Width , 
-		USER_FENSTER_CENTER_Y + ( rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Height + i , 
-		// User_Rect.y + User_Rect.h/2 + (rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Height + i , 
+		0 + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x - 0.5) * Block_Rect.w , 
+		UserCenter_y + ( rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Rect.h + i , 
+		// User_Rect.y + User_Rect.h/2 + (rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Rect.h + i , 
 		HIGHLIGHTCOLOR );
       putpixel( ne_screen , 
-		1 + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x - 0.5) * Block_Width , 
-		USER_FENSTER_CENTER_Y + ( rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Height + i , 
-		// User_Rect.y + User_Rect.h/2 + (rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Height + i , 
+		1 + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x - 0.5) * Block_Rect.w , 
+		UserCenter_y + ( rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Rect.h + i , 
+		// User_Rect.y + User_Rect.h/2 + (rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Rect.h + i , 
 		HIGHLIGHTCOLOR );
 
       // This draws a line at the right border of the current block
       putpixel( ne_screen , 
-		-1 + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x + 0.5) * Block_Width , 
-		USER_FENSTER_CENTER_Y + ( rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Height + i , 
-		// User_Rect.y + User_Rect.h/2 + (rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Height + i , 
+		-1 + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x + 0.5) * Block_Rect.w , 
+		UserCenter_y + ( rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Rect.h + i , 
+		// User_Rect.y + User_Rect.h/2 + (rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Rect.h + i , 
 		HIGHLIGHTCOLOR );
       putpixel( ne_screen , 
-		-2 + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x + 0.5) * Block_Width , 
-		USER_FENSTER_CENTER_Y + ( rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Height + i , 
-		// User_Rect.y + User_Rect.h/2 + (rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Height + i , 
+		-2 + User_Rect.x + (User_Rect.w/2) + (rintf(Me.pos.x)-Me.pos.x + 0.5) * Block_Rect.w , 
+		UserCenter_y + ( rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Rect.h + i , 
+		// User_Rect.y + User_Rect.h/2 + (rintf(Me.pos.y)-Me.pos.y - 0.5 ) * Block_Rect.h + i , 
 		HIGHLIGHTCOLOR );
 
       /*
-	      TargetRectangle.x = USER_FENSTER_CENTER_X 
-		+ ( -Me.pos.x+col-0.5 )*Block_Width;
-	      TargetRectangle.y = USER_FENSTER_CENTER_Y
-		+ ( -Me.pos.y+line-0.5 )*Block_Height;
+	      TargetRectangle.x = UserCenter_x 
+		+ ( -Me.pos.x+col-0.5 )*Block_Rect.w;
+	      TargetRectangle.y = UserCenter_y
+		+ ( -Me.pos.y+line-0.5 )*Block_Rect.h;
 	      SDL_BlitSurface( MapBlockSurfacePointer[ CurLevel->color ][MapBrick] , NULL ,
  			       ne_screen, &TargetRectangle);
       */
@@ -917,28 +911,28 @@ Show_Waypoints(void)
       //--------------------
       // Draw the cross in the middle of the middle of the tile
       //
-      for (i= Block_Width/4; i<3 * Block_Width / 4; i++)
+      for (i= Block_Rect.w/4; i<3 * Block_Rect.w / 4; i++)
 	{
 	  // This draws a (double) line at the upper border of the current block
-	  x = i + User_Rect.x+(User_Rect.w/2)- (( Me.pos.x)-this_wp->x + 0.5) * Block_Width;
-	  y = i + USER_FENSTER_CENTER_Y - (( Me.pos.y)-this_wp->y + 0.5) * Block_Height;
+	  x = i + User_Rect.x+(User_Rect.w/2)- (( Me.pos.x)-this_wp->x + 0.5) * Block_Rect.w;
+	  y = i + UserCenter_y - (( Me.pos.y)-this_wp->y + 0.5) * Block_Rect.h;
 	  if ( ( x < User_Rect.x ) || ( x > User_Rect.x + User_Rect.w ) || ( y < User_Rect. y) || ( y > User_Rect.y + User_Rect.h ) ) continue;
 	  putpixel( ne_screen , x , y , HIGHLIGHTCOLOR );
 
 		    
-	  x = i + User_Rect.x + (User_Rect.w/2) - (( Me.pos.x )-this_wp->x + 0.5) * Block_Width;
-	  y = i + USER_FENSTER_CENTER_Y - (( Me.pos.y)-this_wp->y + 0.5) * Block_Height + 1;
+	  x = i + User_Rect.x + (User_Rect.w/2) - (( Me.pos.x )-this_wp->x + 0.5) * Block_Rect.w;
+	  y = i + UserCenter_y - (( Me.pos.y)-this_wp->y + 0.5) * Block_Rect.h + 1;
 	  if ( ( x < User_Rect.x ) || ( x > User_Rect.x + User_Rect.w ) || ( y < User_Rect. y) || ( y > User_Rect.y + User_Rect.h ) ) continue;
 	  putpixel( ne_screen , x , y , HIGHLIGHTCOLOR );
 	  
 	  // This draws a line at the lower border of the current block
-	  x = i + User_Rect.x + (User_Rect.w/2) - (( Me.pos.x)-this_wp->x + 0.5) * Block_Width;
-	  y = -i + USER_FENSTER_CENTER_Y - (( Me.pos.y )-this_wp->y - 0.5 ) * Block_Height -1;
+	  x = i + User_Rect.x + (User_Rect.w/2) - (( Me.pos.x)-this_wp->x + 0.5) * Block_Rect.w;
+	  y = -i + UserCenter_y - (( Me.pos.y )-this_wp->y - 0.5 ) * Block_Rect.h -1;
 	  if ( ( x < User_Rect.x ) || ( x > User_Rect.x + User_Rect.w ) || ( y < User_Rect. y) || ( y > User_Rect.y + User_Rect.h ) ) continue;
 	  putpixel( ne_screen , x , y , HIGHLIGHTCOLOR );
 
-	  x = i + User_Rect.x + (User_Rect.w/2) - (( Me.pos.x)-this_wp->x + 0.5) * Block_Width;
-	  y = -i + USER_FENSTER_CENTER_Y - ((Me.pos.y)-this_wp->y - 0.5 ) * Block_Height -2;
+	  x = i + User_Rect.x + (User_Rect.w/2) - (( Me.pos.x)-this_wp->x + 0.5) * Block_Rect.w;
+	  y = -i + UserCenter_y - ((Me.pos.y)-this_wp->y - 0.5 ) * Block_Rect.h -2;
 	  if ( ( x < User_Rect.x ) || ( x > User_Rect.x + User_Rect.w ) || ( y < User_Rect. y) || ( y > User_Rect.y + User_Rect.h ) ) continue;
 	  putpixel( ne_screen , x , y , HIGHLIGHTCOLOR );
 	  
@@ -988,11 +982,11 @@ LevelEditor(void)
   int KeymapOffset = 15;
   
   Copy_Rect (User_Rect, rect);
-  Copy_Rect (Full_Screen_Rect, User_Rect);  /// level editor can use the full screen!
+  Copy_Rect (Screen_Rect, User_Rect);  /// level editor can use the full screen!
 
   while ( !Done )
     {
-      usleep(50);
+      SDL_Delay(1);
 
       BlockX=rintf(Me.pos.x);
       BlockY=rintf(Me.pos.y);
@@ -1053,7 +1047,7 @@ LevelEditor(void)
 	  PutString ( ne_screen , KeymapOffset , (k) * FontHeight(Menu_BFont)  , "C...start/end waypoint CONNECTION" ); k++;
 
 	  SDL_Flip ( ne_screen );
-	  while (!FirePressedR() || !EscapePressedR()) usleep(50);
+	  while (!FirePressedR() && !EscapePressedR()) SDL_Delay(1);
 	}
       
       //--------------------
@@ -1284,30 +1278,30 @@ LevelEditMenu (void)
   while (!Weiter)
     {
       SDL_BlitSurface (Menu_Background, NULL, ne_screen, NULL);
-      usleep(50);
+      SDL_Delay(1);
 
-      PutInfluence (FIRST_MENU_ITEM_POS_X, FIRST_MENU_ITEM_POS_Y + (MenuPosition-1.5)*fheight);
+      PutInfluence (Menu_Rect.x, Menu_Rect.y + (MenuPosition-1.5)*fheight);
 
       CenteredPutString ( ne_screen ,  1*FontHeight(Menu_BFont),    "LEVEL EDITOR");
 
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X-xoffs, FIRST_MENU_ITEM_POS_Y + 0*fheight, 
+      PrintString (ne_screen, OptionsMenu_Rect.x-xoffs, Menu_Rect.y + 0*fheight, 
 		   "Quit Level Editor");
 
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X-xoffs, FIRST_MENU_ITEM_POS_Y + 1*fheight, 
+      PrintString (ne_screen, OptionsMenu_Rect.x-xoffs, Menu_Rect.y + 1*fheight, 
 		   "Current: %d.  Level +/-" , CurLevel->levelnum );
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X-xoffs, FIRST_MENU_ITEM_POS_Y + 2*fheight, 
+      PrintString (ne_screen, OptionsMenu_Rect.x-xoffs, Menu_Rect.y + 2*fheight, 
 		   "Change level color: %s", ColorNames[CurLevel->color]);
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X-xoffs, FIRST_MENU_ITEM_POS_Y + 3*fheight, 
+      PrintString (ne_screen, OptionsMenu_Rect.x-xoffs, Menu_Rect.y + 3*fheight, 
 		   "Levelsize in X: %d.  -/+" , CurLevel->xlen );
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X-xoffs, FIRST_MENU_ITEM_POS_Y + 4*fheight, 
+      PrintString (ne_screen, OptionsMenu_Rect.x-xoffs, Menu_Rect.y + 4*fheight, 
 		   "Levelsize in Y: %d.  -/+" , CurLevel->ylen );
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X-xoffs, FIRST_MENU_ITEM_POS_Y + 5*fheight, 
+      PrintString (ne_screen, OptionsMenu_Rect.x-xoffs, Menu_Rect.y + 5*fheight, 
 		   "Level name: %s" , CurLevel->Levelname );
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X-xoffs, FIRST_MENU_ITEM_POS_Y + 6*fheight, 
+      PrintString (ne_screen, OptionsMenu_Rect.x-xoffs, Menu_Rect.y + 6*fheight, 
 		   "Background music: %s" , CurLevel->Background_Song_Name );
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X-xoffs, FIRST_MENU_ITEM_POS_Y + 7*fheight, 
+      PrintString (ne_screen, OptionsMenu_Rect.x-xoffs, Menu_Rect.y + 7*fheight, 
 		   "Level Comment: %s" , CurLevel->Level_Enter_Comment );
-      PrintString (ne_screen, OPTIONS_MENU_ITEM_POS_X-xoffs, FIRST_MENU_ITEM_POS_Y + 8*fheight, 
+      PrintString (ne_screen, OptionsMenu_Rect.x-xoffs, Menu_Rect.y + 8*fheight, 
 		   "Save ship as  'Testship.shp'");
 
       SDL_Flip ( ne_screen );
@@ -1315,7 +1309,7 @@ LevelEditMenu (void)
       key = FALSE;
       while (!key)
 	{
-	  usleep(50);
+	  SDL_Delay(1);
 	  
 	  if (LeftPressed()||RightPressed()||MouseLeftPressed()||MouseRightPressed()||SpacePressed())
 	    key = TRUE;
@@ -1336,7 +1330,7 @@ LevelEditMenu (void)
 		  SaveShip("Testship");
 		  CenteredPutString (ne_screen, 3*FontHeight(Menu_BFont),"Ship saved as 'Testship.shp'\n");
 		  SDL_Flip ( ne_screen );
-		  while ( !FirePressedR() && !EscapePressedR() ) usleep(50);
+		  while ( !FirePressedR() && !EscapePressedR() ) SDL_Delay(1);
 		}
 	      break;
 	    case SET_LEVEL_NAME:
@@ -1344,7 +1338,7 @@ LevelEditMenu (void)
 		{
 		  MenuItemSelectedSound();
 		  DisplayText ("New level name: ",
-			       FIRST_MENU_ITEM_POS_X-50, FIRST_MENU_ITEM_POS_X+ 5*fheight, 
+			       Menu_Rect.x-50, Menu_Rect.x+ 5*fheight, 
 			       &Full_User_Rect);
 		  SDL_Flip( ne_screen );
 		  CurLevel->Levelname = GetString(15, 2);
@@ -1356,7 +1350,7 @@ LevelEditMenu (void)
 		{
 		  MenuItemSelectedSound();
 		  DisplayText ("Bg music filename: ", 
-			       FIRST_MENU_ITEM_POS_X-50, FIRST_MENU_ITEM_POS_X+ 5*fheight, 
+			       Menu_Rect.x-50, Menu_Rect.x+ 5*fheight, 
 			       &Full_User_Rect);
 		  SDL_Flip( ne_screen );
 		  CurLevel->Background_Song_Name=GetString(20, 2);
@@ -1367,7 +1361,7 @@ LevelEditMenu (void)
 		{
 		  MenuItemSelectedSound();
 		  DisplayText ("New level-comment :",
-			       FIRST_MENU_ITEM_POS_X-50, FIRST_MENU_ITEM_POS_X+ 5*fheight, 
+			       Menu_Rect.x-50, Menu_Rect.x+ 5*fheight, 
 			       &Full_User_Rect);
 		  SDL_Flip( ne_screen );
 		  CurLevel->Level_Enter_Comment=GetString(15 , FALSE );
