@@ -43,8 +43,6 @@ int read_variable (char *data, char *var_name, char *fmt, void *var);
 char *homedir = NULL;
 char ConfigDir[255]="\0";
 
-struct timeval now, oneframetimestamp, tenframetimestamp,
-  onehundredframetimestamp, differenz;
 long oneframedelay = 0;
 long tenframedelay = 0;
 long onehundredframedelay = 0;
@@ -125,6 +123,7 @@ read_variable (char *data, char *var_name, char *fmt, void *var)
 #define TAKEOVER_ACTIVATES           "TakeoverActivates"
 #define SHOW_DECALS                  "ShowDecals"
 #define ALL_MAP_VISIBLE              "AllMapVisible"
+#define VID_SCALE_FACTOR             "Vid_ScaleFactor"
 
 /*----------------------------------------------------------------------
  * LoadGameConfig(): load saved options from config-file
@@ -145,13 +144,20 @@ LoadGameConfig (void)
 
   // first we need the user's homedir for loading/saving stuff
   if ( (homedir = getenv("HOME")) == NULL )
-    DebugPrintf ( 0 , "WARNING: Environment does not contain HOME variable...\n\
-Cannot Load or Save settings.\n");
+    {
+      DebugPrintf ( 0 , "WARNING: Environment does not contain HOME variable...using local dir\n");
+      homedir = ".";
+    }
 
   sprintf (ConfigDir, "%s/.freedroidClassic", homedir);
   
   if (stat(ConfigDir, &statbuf) == -1) {
     DebugPrintf (1, "Couldn't stat Config-dir %s, I'll try to create it...", ConfigDir);
+#if __WIN32__
+    _mkdir (ConfigDir);
+    DebugPrintf (1, "ok\n");
+    return (OK);
+#else
     if (mkdir (ConfigDir, S_IREAD|S_IWRITE|S_IEXEC) == -1)
       {
 	DebugPrintf (0, "WARNING: Failed to create config-dir: %s. Giving up...\n", ConfigDir);
@@ -162,22 +168,18 @@ Cannot Load or Save settings.\n");
 	DebugPrintf (1, "ok\n");
 	return (OK);
       }
+#endif
   }
 
   sprintf (fname, "%s/config", ConfigDir);
-  
-  if ( stat (fname, &statbuf) == -1 )
-    {
-      DebugPrintf (0, "Couldn't stat config-file: %s\n", fname);
-      return (ERR);
-    }
-  size = statbuf.st_size;
 
   if( (fp = fopen (fname, "r")) == NULL)
     {
       DebugPrintf (0, "WARNING: failed to open config-file: %s\n");
       return (ERR);
     }
+
+  size = FS_filelength (fp);
   
   // Now read the raw data
   data = MyMalloc (size+10);
@@ -185,6 +187,9 @@ Cannot Load or Save settings.\n");
   data [read_size] = '\0';  // properly terminate as string!
 
   DebugPrintf (2, "Wanted to read %d bytes, got %d bytes\n", size, read_size);
+
+  // windoze doesn't seem to be its numbers right, so let's just close our eyes here..
+#ifndef __WIN32__
   if ( read_size != size )
     {
       DebugPrintf (0, "WARNING: error in reading config-file %s\n Giving up...", fname);
@@ -192,6 +197,8 @@ Cannot Load or Save settings.\n");
       free (data);
       return (ERR);
     }
+#endif
+
   fclose (fp);
 
   if ( read_variable (data, VERSION_STRING, "%s", version_string) == ERR)
@@ -216,6 +223,7 @@ Cannot Load or Save settings.\n");
   read_variable (data, TAKEOVER_ACTIVATES,       "%d", &GameConfig.TakeoverActivates);
   read_variable (data, SHOW_DECALS,              "%d", &GameConfig.ShowDecals);
   read_variable (data, ALL_MAP_VISIBLE,          "%d", &GameConfig.AllMapVisible);
+  read_variable (data, VID_SCALE_FACTOR,         "%f", &GameConfig.scale);
 
   free (data);
 
@@ -260,6 +268,7 @@ SaveGameConfig (void)
   fprintf (fp, "%s = %d\n", TAKEOVER_ACTIVATES, GameConfig.TakeoverActivates);
   fprintf (fp, "%s = %d\n", SHOW_DECALS, GameConfig.ShowDecals);
   fprintf (fp, "%s = %d\n", ALL_MAP_VISIBLE, GameConfig.AllMapVisible);
+  fprintf (fp, "%s = %f\n", VID_SCALE_FACTOR, GameConfig.scale);
 
   fclose (fp);
   return (OK);
@@ -546,8 +555,12 @@ not resolve.... Sorry, if that interrupts a major game of yours.....\n\
 
 
 /*----------------------------------------------------------------------
-  find label in data and read stuff after label into dst using the FormatString
-----------------------------------------------------------------------*/
+ *  find label in data and read stuff after label into dst using the FormatString
+ *
+ * NOTE!!: be sure dst is large enough for data read by FormatString, or
+ * sscanf will crash!!
+ *
+ *----------------------------------------------------------------------*/
 void
 ReadValueFromString (char* data, char* label, char* FormatString, void* dst)
 {
@@ -570,7 +583,7 @@ ReadValueFromString (char* data, char* label, char* FormatString, void* dst)
 }
 
 /*-----------------------------------------------------------------
- * find a given filename in subdir relative to DATADIR, 
+ * find a given filename in subdir relative to FD_DATADIR, 
  *
  * if you pass NULL as "subdir", it will be ignored
  *
@@ -616,7 +629,7 @@ find_file (char *fname, char *subdir, int use_theme, int critical)
       if (i==0)
 	strcpy (File_Path, "..");   /* first try local subdirs */
       if (i==1)
-	strcpy (File_Path, DATADIR); /* then the DATADIR */
+	strcpy (File_Path, FD_DATADIR); /* then the FD_DATADIR */
 
       strcat (File_Path, "/");
       strcat (File_Path, subdir);
@@ -699,7 +712,7 @@ Pause (void)
       DisplayBanner (NULL, NULL, 0);
       Assemble_Combat_Picture ( DO_SCREEN_UPDATE );
 
-      usleep (50);
+      SDL_Delay (1);
 
       ComputeFPSForThisFrame();
 
@@ -722,11 +735,6 @@ Pause (void)
 /*@Function============================================================
 @Desc: This function starts the time-taking process.  Later the results
        of this function will be used to calculate the current framerate
-
-       Two methods of time-taking are available.  One uses the SDL 
-       ticks.  This seems LESS ACCURATE.  The other one uses the
-       standard ansi c gettimeofday functions and are MORE ACCURATE
-       but less convenient to use.
 @Ret: 
 * $Function----------------------------------------------------------*/
 void 
@@ -762,10 +770,6 @@ StartTakingTimeForFPSCalculation(void)
        NOTE:  To query the actual framerate a DIFFERENT function must
        be used, namely Frame_Time().
 
-       Two methods of time-taking are available.  One uses the SDL 
-       ticks.  This seems LESS ACCURATE.  The other one uses the
-       standard ansi c gettimeofday functions and are MORE ACCURATE
-       but less convenient to use.
 @Ret: 
 * $Function----------------------------------------------------------*/
 void 
@@ -902,11 +906,9 @@ int
 MyRandom (int UpperBound)
 {
   float tmp;
-  int PureRandom;
   int dice_val;    /* the result in [0, Obergrenze] */
 
-  PureRandom = rand ();
-  tmp = 1.0*PureRandom/RAND_MAX; /* random number in [0;1] */
+  tmp = 1.0* rand() / RAND_MAX; /* random number in [0;1] */
 
   /* 
    * we always round OFF for the resulting int, therefore
@@ -1008,8 +1010,8 @@ Teleport (int LNum, int X, int Y)
 void
 Terminate (int ExitCode)
 {
-  printf("\n----------------------------------------------------------------------");
-  printf("\nTermination of Freedroid initiated...");
+  DebugPrintf(0,"\n----------------------------------------------------------------------");
+  DebugPrintf(0,"\nTermination of Freedroid initiated...");
 
   if (ExitCode == OK)
     {
@@ -1019,7 +1021,7 @@ Terminate (int ExitCode)
       SaveHighscores ();
     }
 
-  printf("Thank you for playing Freedroid.\n\n");
+  DebugPrintf(0, "Thank you for playing Freedroid.\n\n");
   SDL_Quit();
   exit (ExitCode);
   return;
@@ -1038,6 +1040,10 @@ MyMalloc (long Mamount)
 {
   void *Mptr = NULL;
 
+  // make Gnu-compatible even if on a broken system:
+  if (Mamount == 0)
+    Mamount = 1;
+
   if ((Mptr = calloc (1, (size_t) Mamount)) == NULL)
     {
       DebugPrintf (0, " MyMalloc(%ld) did not succeed!\n", Mamount);
@@ -1047,4 +1053,24 @@ MyMalloc (long Mamount)
   return Mptr;
 }				// void* MyMalloc(long Mamount)
 
+/*----------------------------------------------------------------------
+ * FS_filelength().. (taken from quake2)
+ * 		contrary to stat() this fct is nice and portable, 
+ *----------------------------------------------------------------------*/
+int
+FS_filelength (FILE *f)
+{
+  int		pos;
+  int		end;
+
+  pos = ftell (f);
+  fseek (f, 0, SEEK_END);
+  end = ftell (f);
+  fseek (f, pos, SEEK_SET);
+  
+  return end;
+}
+
+
+
 #undef _misc_c
