@@ -55,22 +55,9 @@ extern bool show_cursor;
 
 #define WAIT_ELEVATOR		9	/* warte, bevor Lift weitergeht */
 
-#define MENUITEMHEIGHT 		4*77
-#define MENUITEMLENGTH 		50*2
-
 #define MENUTEXT_X	(132 + USERFENSTERPOSX + 5 )
 
 
-SDL_Rect Cons_Header_Rect = {75, BANNER_HEIGHT+40, SCREENLEN - 80, 135 - BANNER_HEIGHT};
-SDL_Rect Cons_Menu_Rect = {60, 180, 100, 256};
-SDL_Rect Cons_Text_Rect = {180, 180, SCREENLEN-185, SCREENHEIGHT - 185}; 
-
-SDL_Rect Cons_Menu_Rects[4] = {
-  {60, 180 + 0*64, 100, 62},
-  {60, 181 + 1*64, 100, 62},
-  {60, 181 + 2*64, 100, 62},
-  {60, 181 + 3*64, 100, 62} };
-
 SDL_Rect up_rect;
 SDL_Rect down_rect;
 SDL_Rect left_rect;
@@ -88,7 +75,7 @@ EnterLift (void)
   int curLevel;
   int curLift, upLift, downLift, liftrow;
 
-  DebugPrintf (2, "\nvoid EnterLiftator(void): Function call confirmed.");
+  DebugPrintf (2, "\nvoid EnterLift(void): Function call confirmed.");
 
   /* Prevent distortion of framerate by the delay coming from 
    * the time spend in the menu. */
@@ -241,10 +228,10 @@ ShowLifts (int level, int liftrow)
   SDL_Rect src, dst;
   int i;
   SDL_Color lift_bg_color = {0,0,0};  /* black... */
-  int xoffs = (User_Rect.w - 578)/2;
-  int yoffs = (User_Rect.h - 211)/2;
+  int xoffs = User_Rect.w/20;
+  int yoffs = User_Rect.h/5;
 
-  SDL_ShowCursor(SDL_DISABLE);
+  SDL_ShowCursor (SDL_DISABLE);
   // fill the user fenster with some color
   Fill_Rect (User_Rect, lift_bg_color);
 
@@ -324,7 +311,7 @@ EnterKonsole (void)
 
   while (!ReenterGame)
     {
-      usleep(50);
+      SDL_Delay(1);
       if (show_cursor) SDL_ShowCursor (SDL_ENABLE);
       else SDL_ShowCursor (SDL_DISABLE);
 
@@ -398,7 +385,7 @@ EnterKonsole (void)
 	      ShowLifts (CurLevel->levelnum, -1);
 
 	      while (! (FirePressedR() || EscapePressedR() || MouseRightPressedR() ))
-		usleep(50);
+		SDL_Delay(1);
 	      PaintConsoleMenu(pos, 0);
 	      break;
 	    default: 
@@ -457,10 +444,10 @@ PaintConsoleMenu (int pos, int flag)
 
     } // only if not UPDATE_ONLY was required 
 
-  src.x=(MENUITEMLENGTH+2)*pos;
-  src.y=0;
-  src.w=MENUITEMLENGTH;
-  src.h=MENUITEMHEIGHT;
+  src.x = Cons_Menu_Rects[0].w * pos;
+  src.y = 0;
+  src.w = Cons_Menu_Rect.w;
+  src.h = 4 * Cons_Menu_Rect.h;
   SDL_BlitSurface (console_pic, &src, ne_screen, &Cons_Menu_Rect);
 
   SDL_Flip (ne_screen);
@@ -496,7 +483,7 @@ ShowDeckMap (Level deck)
   Me.pos.y=tmp.y;
 
   while (! (FirePressedR() || EscapePressedR() || MouseRightPressedR() )) 
-    usleep(50);
+    SDL_Delay(1);
 
   SetCombatScaleTo (1.0);
 
@@ -536,8 +523,8 @@ CursorIsOnRect (SDL_Rect *rect)
 {
   point CurPos;
 
-  CurPos.x = input_axis.x + (USER_FENSTER_CENTER_X - 16);
-  CurPos.y = input_axis.y + (USER_FENSTER_CENTER_Y - 16);
+  CurPos.x = input_axis.x + (UserCenter_x - 16);
+  CurPos.y = input_axis.y + (UserCenter_y - 16);
 
   if ( (CurPos.x >= rect->x) && (CurPos.x <= rect->x + rect->w) )
     if ( (CurPos.y >= rect->y) && (CurPos.y <= rect->y + rect->h) )
@@ -571,7 +558,7 @@ GreatDruidShow (void)
   while (!finished)
     {
       show_droid_portrait (Cons_Droid_Rect, droidtype, DROID_ROTATION_TIME, 0);
-      usleep(50);
+      SDL_Delay(1);
       if (show_cursor) SDL_ShowCursor (SDL_ENABLE);
       else SDL_ShowCursor (SDL_DISABLE);
 
@@ -705,7 +692,7 @@ Brain : %s",   droidtype+1, Classes[Druidmap[droidtype].class],
       show_title = TRUE;
       show_arrows = TRUE;
       sprintf( InfoText , "\
-Armamant : %s\n\
+Armament : %s\n\
 Sensors  1: %s\n\
                     2: %s\n\
                     3: %s", 
@@ -832,7 +819,6 @@ show_droid_portrait (SDL_Rect dst, int droid_type, float cycle_time, int flags)
       // now see if its a jpg, then we add some transparency by color-keying:
       if (IMG_isJPG(packed_portraits[droid_type]))
 	{
-	  // non SDL_SetColorKey (tmp, SDL_SRCCOLORKEY|SDL_RLEACCEL, TransparentPixel);
 	  droid_pics = SDL_DisplayFormat (tmp);
 	} // else assume it's png ;)
       else
@@ -842,15 +828,21 @@ show_droid_portrait (SDL_Rect dst, int droid_type, float cycle_time, int flags)
       SDL_FreeSurface (tmp);
       SDL_RWseek (packed_portraits[droid_type], 0, SEEK_SET);
 
+
+      // do we have to scale the droid pics
+      if (GameConfig.scale != 1.0)
+	ScalePic (&droid_pics, GameConfig.scale);
+
       last_droid_type = droid_type;
     }
 
   num_frames = droid_pics->w / Portrait_Rect.w;
+
   // sanity check
   if ( num_frames == 0)
     {
-      DebugPrintf (0, "WARNING: width of droid-pic %s is less than the standard %d\n",
-		   Druidmap[droid_type].druidname, Portrait_Rect.w);
+      DebugPrintf (0, "WARNING: Only one frame found. Width droid-pics=%d, Frame-width=%d\n",
+		   droid_pics->w, Portrait_Rect.w);
       num_frames = 1;       // continue and hope for the best
     }
 
